***************
Link Prediction
***************

.. automodule:: networkx.algorithms.link_prediction
.. autosummary::
   :toctree: generated/

   resource_allocation_index
   jaccard_coefficient
   adamic_adar_index
   preferential_attachment
   cn_soundarajan_hopcroft
   ra_index_soundarajan_hopcroft
   within_inter_cluster
